#
# spec file for package python-fangfrisch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-fangfrisch
Version:        1.9.0
Release:        1.3
Summary:        Update and verify unofficial Clam Anti-Virus signatures
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/rseichter/fangfrisch
Source:         https://github.com/rseichter/fangfrisch/archive/refs/tags/%{version}.tar.gz
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-SQLAlchemy
Requires:       python-requests
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Fangfrisch (German for "freshly caught") is a sibling of the Clam
Anti-Virus freshclam utility. It allows downloading virus definition
files that are not official ClamAV canon, e.g. from Sanesecurity and
URLhaus. Fangfrisch was designed with security in mind, to be run by an
unprivileged user only.

%prep
%autosetup -p1 -n fangfrisch-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests
%python_clone -a %{buildroot}%{_bindir}/fangfrisch

%post
%python_install_alternative fangfrisch

%postun
%python_uninstall_alternative fangfrisch

%check
# make check wants to do network... cant do this in OBS
#python_expand script -eqc "pytest-%%{$python_version} -vv -s" /dev/null

%files %{python_files}
%license LICENSE
%doc CHANGELOG.rst README.rst
%{_bindir}/fangfrisch
%{python_sitelib}/fangfrisch
%{python_sitelib}/fangfrisch-%{version}*-info
%python_alternative %{_bindir}/fangfrisch

%changelog
* Thu Nov  7 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC, switch to pyproject_* macros.
* Thu Nov  7 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 1.9.0 (2024-03-08):
  - The logic for on_update* has been largely rewritten. As a
    user-visible side effect, detailed debugging information
    about 'on_update_*' tasks is now available.
  - For improved flexibility, configuration sections
    may now override global 'on_update_exec' and
    'on_update_timeout'. Eearlier Fangfrisch versions only
    examined the DEFAULTS section.
  - Add internal default configurations for providers InterServer
    (https://www.interserver.net/) and Fangfrisch News
    (https://rseichter.github.io/fangfrisch/#ffnews). As per
    usual, these new providers are disabled by default.
- Update to 1.8.1 (2024-02-21):
  - Python unit tests requiring network connections are now
    disabled by default to facilitate sandboxed testing. Set
    environment variable NETWORK_TESTS=1 to enable these tests.
- Update to 1.8.0 (2024-02-14):
  - Sanesecurity (https://sanesecurity.com) provider default
    configuration overhaul. Switch to a less congested mirror
    site, add/remove several signature URLs.
  - Modernise Python build re PEP 517
    (https://peps.python.org/pep-0517/).
- Update to 1.7.0 (2024-02-03):
  - Support user-defined connection timeouts.
- Update to 1.6.1 (2023-02-21):
  - Require SQLAlchemy version 1.4 or higher. Version 1.3 is no
    longer maintained by the SQLAlchemy developers.
- Update to 1.6.0 (2023-02-18):
  - Use Python context management protocol to improve SQLAlchemy
    session handling, in particular to more reliably release
    resources like database connections.
* Mon Apr 25 2022 Marcus Meissner <meissner@suse.com>
- fangfrisch - fetch third party clamav signatures
